@@ -1,8 +1,10 @@
-from audiostack.helpers.request_interface import RequestInterface
-from audiostack.helpers.request_types import RequestTypes
+import os
+from typing import Any
+
 from audiostack.helpers.api_item import APIResponseItem
 from audiostack.helpers.api_list import APIResponseList
-import os
+from audiostack.helpers.request_interface import RequestInterface
+from audiostack.helpers.request_types import RequestTypes
 
 
 class File:
@@ -10,25 +12,25 @@ class File:
     interface = RequestInterface(family=FAMILY)
 
     class Item(APIResponseItem):
-        def __init__(self, response) -> None:
+        def __init__(self, response: dict) -> None:
             super().__init__(response)
             self.fileId = self.data["fileId"]
             self.filePath = self.data["filePath"]
             self.url = self.data.get("url", None)
 
-        def delete(self):
+        def delete(self) -> APIResponseItem:
             return File.delete(self.fileId)
-    
-        def download(self, fileName="", path="./") -> None:
+
+        def download(self, fileName: str = "", path: str = "./") -> None:
             if not fileName:
                 fileName = self.filePath.split("/")[-1]
             RequestInterface.download_url(self.url, destination=path, name=fileName)
 
     class List(APIResponseList):
-        def __init__(self, response, list_type) -> None:
+        def __init__(self, response: dict, list_type: str) -> None:
             super().__init__(response, list_type)
 
-        def resolve_item(self, list_type, item):
+        def resolve_item(self, list_type: str, item: Any) -> "File.Item":
             if list_type == "items" or list_type == "files":
                 return File.Item({"data": item})
             else:
@@ -42,7 +44,6 @@ class File:
         category: str = "",
         tags: list = [],
         metadata: dict = {},
-        filePath: str = None,
     ) -> Item:
         if not os.path.isfile(localPath):
             raise Exception("Supplied file does not eixst")
@@ -70,9 +71,7 @@ class File:
         url = response.data["fileUploadUrl"]
         fileId = response.data["fileId"]
 
-        status = File.interface.send_upload_request(
-            local_path=localPath, upload_url=url
-        )
+        File.interface.send_upload_request(local_path=localPath, upload_url=url)
         return File.get(fileId)
 
     @staticmethod
@@ -83,7 +82,6 @@ class File:
         tags: list = [],
         metadata: dict = {},
     ) -> Item:
-
         data = {
             "filePath": uploadPath,
             "url": url,
@@ -108,7 +106,6 @@ class File:
         tags: list = [],
         metadata: dict = {},
     ) -> Item:
-
         data = {
             "filePath": filePath,
             "category": category,
@@ -116,7 +113,7 @@ class File:
             "metadata": metadata,
         }
 
-        r = File.interface.send_request(
+        File.interface.send_request(
             rtype=RequestTypes.PATCH,
             route=f"file/id/{fileId}",
             json=data,
@@ -128,10 +125,15 @@ class File:
         r = File.interface.send_request(
             rtype=RequestTypes.GET, route="file/id", path_parameters=fileId
         )
+        while r["statusCode"] == 202:
+            print("Response in progress please wait...")
+            r = File.interface.send_request(
+                rtype=RequestTypes.GET, route="file/id", path_parameters=fileId
+            )
         return File.Item(r)
 
     @staticmethod
-    def delete(fileId: str) -> str:
+    def delete(fileId: str) -> APIResponseItem:
         r = File.interface.send_request(
             rtype=RequestTypes.DELETE, route="file/id", path_parameters=fileId
         )
@@ -167,24 +169,23 @@ class Folder:
     interface = RequestInterface(family=FAMILY)
 
     class Item(APIResponseItem):
-        def __init__(self, response) -> None:
+        def __init__(self, response: dict) -> None:
             super().__init__(response)
             self.folders = Folder.List(response, list_type="folders")
             self.files = File.List(response, list_type="files")
 
     class List(APIResponseList):
-        def __init__(self, response, list_type) -> None:
+        def __init__(self, response: dict, list_type: str) -> None:
             super().__init__(response, list_type)
 
-        def resolve_item(self, list_type, item):
+        def resolve_item(self, list_type: str, item: Any) -> dict:
             if list_type == "folders":
                 return {"data": item}
             else:
                 raise Exception()
 
     @staticmethod
-    def create(name) -> Item:
-
+    def create(name: Any) -> APIResponseItem:
         r = File.interface.send_request(
             rtype=RequestTypes.POST,
             route="folder",
@@ -193,14 +194,14 @@ class Folder:
         return APIResponseItem(r)
 
     @staticmethod
-    def list(folder: str) -> Item:
+    def list(folder: str) -> "Folder.Item":
         r = File.interface.send_request(
             rtype=RequestTypes.GET, route="folder", query_parameters={"folder": folder}
         )
         return Folder.Item(r)
 
     @staticmethod
-    def delete(folder: str, delete_files=False) -> str:
+    def delete(folder: str, delete_files: bool = False) -> APIResponseItem:
         r = File.interface.send_request(
             rtype=RequestTypes.DELETE,
             route="folder",
