@@ -1,15 +1,14 @@
+from audiostack.helpers.api_item import APIResponseItem
 from audiostack.helpers.request_interface import RequestInterface
 from audiostack.helpers.request_types import RequestTypes
-from audiostack.helpers.api_item import APIResponseItem
-from audiostack.helpers.api_list import APIResponseList
 
 
 class Documentation:
     interface = RequestInterface(family="")
 
     @staticmethod
-    def docs_for_service(service: object) -> dict:
-        service = service.__name__.lower()
+    def docs_for_service(service: object) -> APIResponseItem:
+        service = service.__name__.lower()  # type: ignore
 
         r = Documentation.interface.send_request(
             rtype=RequestTypes.GET,
